==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-server/src/main/java/org/apache/hadoop/hbase/backup/FailedArchiveException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.backup;

import org.apache.hadoop.fs.Path;
import org.apache.hadoop.hbase.classification.InterfaceAudience;

import java.io.IOException;
import java.util.Collection;

/**
 * Exception indicating that some files in the requested set could not be archived.
 */
@InterfaceAudience.Private
public class FailedArchiveException extends IOException {
  private final Collection<Path> failedFiles;

  public FailedArchiveException(String message, Collection<Path> failedFiles) {
    super(message);
    this.failedFiles = failedFiles;
  }

  public Collection<Path> getFailedFiles() {
    return failedFiles;
  }

  @Override
  public String getMessage() {
    return new StringBuilder(super.getMessage())
        .append("; files=")
        .append(failedFiles)
        .toString();
  }
}

==> hbase-2.4.17-src.tar.gz: hbase-2.4.17/hbase-server/src/main/java/org/apache/hadoop/hbase/backup/FailedArchiveException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.backup;

import java.io.IOException;
import java.util.Collection;
import org.apache.hadoop.fs.Path;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Exception indicating that some files in the requested set could not be archived.
 */
@InterfaceAudience.Private
public class FailedArchiveException extends IOException {
  private final Collection<Path> failedFiles;

  public FailedArchiveException(String message, Collection<Path> failedFiles) {
    super(message);
    this.failedFiles = failedFiles;
  }

  public Collection<Path> getFailedFiles() {
    return failedFiles;
  }

  @Override
  public String getMessage() {
    return new StringBuilder(super.getMessage()).append("; files=").append(failedFiles).toString();
  }
}
